CustomImageView class

A flexible image view widget that supports multiple image sources.

Displays images from:

  • Network URLs (with caching)
  • Asset paths (PNG, JPG, etc.)
  • SVG files
  • Local file paths
  • Lottie JSON animations

Example:

CustomImageView(
  imagePath: 'https://example.com/image.png',
  height: 200,
  width: double.infinity,
  fit: BoxFit.cover,
)
Inheritance

Constructors

CustomImageView({Key? key, String? imagePath, double? height, double? width, Color? color, BoxFit? fit, Alignment? alignment, VoidCallback? onTap, BorderRadius? radius, EdgeInsetsGeometry? margin, BoxBorder? border, BlendMode? colorBlendMode, bool usePlaceholder = true, Duration fadeInDuration = const Duration(milliseconds: 300), Duration fadeOutDuration = const Duration(milliseconds: 300), Widget? errorWidget})
const

Properties

alignment Alignment?
final
border BoxBorder?
final
color Color?
final
colorBlendMode BlendMode?
final
errorWidget Widget?
final
fadeInDuration Duration
final
fadeOutDuration Duration
final
fit BoxFit?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
imagePath String?
imagePath is required parameter for showing image.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
final
onTap VoidCallback?
final
radius BorderRadius?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usePlaceholder bool
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited